@@ -79,6 +79,7 @@ Development
 Sources are tracked on http://bitbucket.org/Mekk/calibre_utils
 
 """
+from __future__ import print_function
 
 from collections import namedtuple
 from mekk.calibre.calibre_util import  \
@@ -126,7 +127,7 @@ def locate_potential_isbn_files():
                                title=book.title,
                                files=files)
         if item_no > 0 and item_no % CONFIG.progress_report_every == 0:
-            print "Info: %d files found, %d checked" % (item_no, checked_count)
+            print("Info: %d files found, %d checked" % (item_no, checked_count))
 
 
 def find_files_with_new_isbn():
@@ -150,16 +151,16 @@ def find_files_with_new_isbn():
                 raise Exception(
                     "ISBN conflict in %s: %s" % (str(item), str(candid)))
         except KeyboardInterrupt:
-            print "Ctrl-C pressed, stopping"
+            print("Ctrl-C pressed, stopping")
             break
         except: #  Exception as e:
             error_count += 1
-            print "Exception while handling book '%s'. Details:" % (
-                item.title)
+            print("Exception while handling book '%s'. Details:" % (
+                item.title))
             traceback.print_exc()
-            print
+            print()
             if error_count > ERROR_LIMIT:
-                print "Too many errors (%d) happened. Stopping" % error_count
+                print("Too many errors (%d) happened. Stopping" % error_count)
                 break
 
 ############################################################
